==> haskell-lifted-base-0.2.3.6-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-lifted-base/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.6
id: lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
key: lifte_5D91cjXHiv39Kr8gZ3cfue
license: BSD3
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Exception.Lifted Control.Concurrent.MVar.Lifted
    Control.Concurrent.Chan.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Concurrent.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/lifted-base-0.2.3.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/lifted-base-0.2.3.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/lifted-base-0.2.3.6
hs-libraries: HSlifted-base-0.2.3.6-5D91cjXHiv39Kr8gZ3cfue
includes:
    inlinable.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.6-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-lifted-base/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.6
id: lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
key: lifte_I9TR5C3q4Z0Cg36jJy4jWT
license: BSD3
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Exception.Lifted Control.Concurrent.MVar.Lifted
    Control.Concurrent.Chan.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Concurrent.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/lifted-base-0.2.3.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/lifted-base-0.2.3.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/lifted-base-0.2.3.6
hs-libraries: HSlifted-base-0.2.3.6-I9TR5C3q4Z0Cg36jJy4jWT
includes:
    inlinable.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
